pub struct FourierNetworkCodec {
pub fourier_features: NonZeroUsize,
pub fourier_scale: Positive<f64>,
pub num_blocks: NonZeroUsize,
pub learning_rate: Positive<f64>,
pub num_epochs: usize,
pub mini_batch_size: Option<NonZeroUsize>,
pub seed: u64,
pub version: StaticCodecVersion<0, 1, 0>,
}Expand description
Fourier network codec which trains and overfits a fourier feature neural network on encoding and predicts during decoding.
The approach is based on the papers by Tancik et al. 2020 (https://dl.acm.org/doi/abs/10.5555/3495724.3496356) and by Huang and Hoefler 2020 (https://arxiv.org/abs/2210.12538).
Fields
fourier_features: NonZeroUsizeThe number of Fourier features that the data coordinates are projected to
fourier_scale: Positive<f64>The standard deviation of the Fourier features
num_blocks: NonZeroUsizeThe number of blocks in the network
learning_rate: Positive<f64>The learning rate for the Adam optimizer
num_epochs: usizeThe number of epochs for which the network is trained
mini_batch_size: Option<NonZeroUsize>The optional mini-batch size used during training
Setting the mini-batch size to None disables the use of batching,
i.e. the network is trained using one large batch that includes the
full data.
seed: u64The seed for the random number generator used during encoding
version: StaticCodecVersion<0, 1, 0>The codec’s encoding format version. Do not provide this parameter explicitly.